address_to_coords: Convert addresses to coordinates
Description
The function address_to_coords can be used to find coordinates to supplied Norwegian addresses. Internet access is required as the function utilizes the Norwegian Mapping Authority’s address API.
Usage
address_to_coords(zip_code, address, format = "sf", crs_out = 25833)
Value
Object with coordinates to the supplied addresses.
Arguments
zip_code
Character vector with zip codes.
address
Character vector with addresses (street name and house number).
format
Format of the returned object. Default value is set to “sf” (which returns an sf object). It is also possible set the format to “tibble” or “data.frame”.
crs_out
Numeric vector with the chosen coordinate reference system (CRS). Default value is set to CRS 25833.
Details
If there are no coordinates found for the supplied address it means that it does not exist in Matrikkelen - Norway's official property register. See www.rettikartet.no to search for existing addresses.