powered by
The function coords_to_google can be used to convert coordinates of an sf object to a format that is easy to copy and paste into Google Maps.
coords_to_google
sf
coords_to_google(coords, crs_out = 25833)
An sf object with a new column added (coords_google), and an addtional sf geometry column with the chosen CRS.
coords_google
An sf object with a geometry column that will be converted to CRS 4326.
CRS 4326
Chosen coordinate reference system (CRS) for the geometry column of the returned sf object.
address_to_coords(zip_code = "0185", address = "Schweigaards gate 10") %>% coords_to_google()
Run the code above in your browser using DataLab