- vegnett
The Norwegian road network as an sf object, downloaded from Geonorge.
- crs_out
Numeric vector with the chosen coordinate reference system (CRS). The default value is set to CRS 25833.
- year
Numeric vector with the year the road network is from. Due to changes in the format of the files between 2021 and 2022, the most important thing is to choose between the "old" format (-2021) or the new format (2022-). The default value is set to 2022. Please see the example for the column names for 2021 and earlier.
- fromnodeID
Character vector with the name of the column indicating the from node ID. Default value is set to FROMNODE (column name in 2022).
- tonodeID
Character vector with the name of the column indicating the to node ID. Default value is set to TONODE (column name in 2022).
- FT_minutes
Character vector with the name of the column that contains the cost in minutes from fromnodeID to tonodeID (FT). Default value is set to DRIVETIME_FW (column name in 2022).
- TF_minutes
Character vector with the name of the column that contains the cost in minutes from tonodeID to fromnodeID (TF). Default value is set to DRIVETIME_BW (column name in 2022).
- meters
Character vector with the name of the column that contains the cost in meters (equal for FT and TF). Default value is set to SHAPE_LENGTH (column name in 2022).
- turn_restrictions
Logical. Default value is FALSE. If TRUE turn restrictions will be added to the road network. The turn restrictions layer from the road network file has to be loaded before this can be used (and the object has to be called turnrestrictions_geom). Due to errors in the turn restrictions file for 2022 it is not recommended to use this feature for now.
- ferry
Logical/numeric vector. Default value is TRUE which means that all edges that involve ferries are given their original drive time (somewhere between 10 and 13 km/h). If a numeric value is supplied, the cost for all edges involving ferries will be converted to the supplied value in km/h.